<?php

namespace Packages\Product\Http\Controllers;
use App\Http\Controllers\Controller;
use Packages\Product\Http\Requests\AttributeRequest;
use Packages\Product\Models\Attribute;
use Illuminate\Http\Request;

class AttributeController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $attributes = Attribute::orderBy('id','DESC')->get();
        return view('product::attributes.index', compact('attributes'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
       return view('product::attributes.create');

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(AttributeRequest $request)
    {
        $data = [
            'title' => $request->title,
            'key' => $request->key,
            'use_in_veriation' => $request->use_in_veriation,
        ];
        $attribute = Attribute::create($data);
        $msg = 'ذخیره ویژگی با موفقیت انجام شد ';
        return redirect(route('attributes.index', $attribute->id))->with('success', $msg);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Attribute  $attribute
     * @return \Illuminate\Http\Response
     */
    public function show(Attribute $attribute)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Attribute  $attribute
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $attribute = Attribute::findOrFail( $id );
        $attributes  = Attribute::orderBy('id')->get();
        $msg = 'ذخیره ویژگی با موفقیت انجام شد ';
        return view('product::attributes.edit', compact('attribute', 'attributes'))->with('success', $msg);

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Attribute  $attribute
     * @return \Illuminate\Http\Response
     */
    public function update(AttributeRequest $request, Attribute $attribute)
    {
        $data = [
            'title' => $request->title,
            'key' => $request->key,
            'use_in_veriation' => $request->use_in_veriation,
        ];
        $attribute->update($data);
//        dd($attribute);
        $msg = 'ویرایش ویژگی با موفقیت انجام شد ';
        return redirect(route('attributes.index', $attribute->id))->with('success', $msg);

    }
    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Attribute  $attribute
     * @return \Illuminate\Http\Response
     */
    public function destroy(Attribute $attribute)
    {
        $attribute->delete();
        {
            return back();
        }
    }
}
