<?php

namespace Packages\Product\Models;
use App\Models\Category;
use App\Models\Upload;
use Illuminate\Database\Eloquent\Model;
use App\User;
use Illuminate\Database\Eloquent\SoftDeletes;
use Cviebrock\EloquentSluggable\Sluggable;

class Product extends Model
{
    use Sluggable;
    use SoftDeletes;
  protected $fillable = ['title', 'discription', 'price', 'creator_id', 'type', 'status', 'sale_price', 'sku', 'ReleaseStatus'];

    public function user()
    {
        return $this->belongsTo(User::class, 'creator_id', 'id');
    }
    public function categories()
    {
        return $this->morphToMany(Category::class, 'categorizable');
    }
    public function attributes()
    {
        return $this->morphToMany(Attribute::class, 'attributable');
    }
    public function uploads()
    {
        return $this->morphMany(Upload::class, 'uploadable');
    }
    public function getGalleryImagesAttribute(){

        return $this->uploads->where('type', 'gallery_image');
    }
    public function getFeaturedImageAttribute(){
        return $this->uploads->where('type', 'featured_image')->first();
    }
    public function getTypeAttribute($value)
    {
        switch ($value) {
            case 0:
                $type = 'ساده';
                break;
            case 1:
                $type = 'متغیر';
                break;
            case 2:
                $type = 'باندل';
                break;
            default:
                $type = '';
        }
        return $type;
    }
    public function getStatusAttribute($value)
    {
        switch ($value) {
            case 0:
                $status = 'ناموجود';
                break;
            case 1:
                $status = 'موجود';
                break;
            default:
                $status = '';
        }
        return $status;
    }
    public function getReleaseStatusAttribute($value)
    {
        switch ($value) {
            case 'draft':
                $ReleaseStatus = 'پیشنویس';
                break;
            case 'pending':
                $ReleaseStatus = 'در انتظار انتشار';
                break;
                case 'published':
                $ReleaseStatus = 'منتشر شده';
                break;
            default:
                $ReleaseStatus = '';
        }
        return $ReleaseStatus;
    }
    public function sluggable()
    {
        return [
            'slug' => [
                'source' => 'title'
            ]
        ];
    }
}
